@@ -7,6 +7,8 @@ use std::time::Duration;
 fn usage() -> Result<()> {
     let git_version = Command::new("git").arg("--version").exec()?;
     assert_eq!(Some(0), git_version.exit_code());
+    let cmd = Command::collect("git", 1)?;
+    assert_eq!(1, cmd.len());
     Ok(())
 }
 
@@ -18,6 +20,7 @@ fn timeout() -> Result<()> {
         .arg("HEAD")
         .timeout(Duration::new(0, 0))
         .exec()?;
+    println!("{:#?}", cmd);
     assert_eq!(Status::TimedOut, cmd.status());
     Ok(())
 }
